@@ -63,6 +63,7 @@ class Network:
     def __init__(
         self,
         lcd_endpoint: str ,
+        tm_websocket_endpoint: str,
         grpc_endpoint: str ,
         grpc_exchange_endpoint: str ,
         chain_id: str ,
@@ -70,6 +71,7 @@ class Network:
         env: str
     ):
         self.lcd_endpoint = lcd_endpoint
+        self.tm_websocket_endpoint = tm_websocket_endpoint
         self.grpc_endpoint = grpc_endpoint
         self.grpc_exchange_endpoint = grpc_exchange_endpoint
         self.chain_id = chain_id
@@ -80,6 +82,7 @@ class Network:
     def devnet(cls):
         return cls(
             lcd_endpoint='https://devnet.lcd.injective.dev',
+            tm_websocket_endpoint='wss://devnet.tm.injective.dev/websocket',
             grpc_endpoint='devnet.injective.dev:9900',
             grpc_exchange_endpoint='devnet.injective.dev:9910',
             chain_id='injective-777',
@@ -91,6 +94,7 @@ class Network:
     def testnet(cls):
         return cls(
             lcd_endpoint='https://k8s.testnet.lcd.injective.network',
+            tm_websocket_endpoint='wss://k8s.testnet.tm.injective.network/websocket',
             grpc_endpoint='k8s.testnet.chain.grpc.injective.network:443',
             grpc_exchange_endpoint='k8s.testnet.exchange.grpc.injective.network:443',
             chain_id='injective-888',
@@ -102,7 +106,6 @@ class Network:
     def mainnet(cls, node='k8s'):
         nodes = [
             'k8s',
-            'lb',
             'sentry0',  # us, prod
             'sentry1',  # us, prod
             'sentry2',  # us, staging
@@ -111,17 +114,20 @@ class Network:
         if node not in nodes:
             raise ValueError('Must be one of {}'.format(nodes))
 
-        if node == 'lb' or node == 'k8s':
+        if node == 'k8s':
             lcd_endpoint='https://k8s.mainnet.lcd.injective.network'
+            tm_websocket_endpoint='wss://k8s.mainnet.tm.injective.network/websocket'
             grpc_endpoint='k8s.mainnet.chain.grpc.injective.network:443'
             grpc_exchange_endpoint='k8s.mainnet.exchange.grpc.injective.network:443'
         else:
             lcd_endpoint='https://lcd.injective.network'
+            tm_websocket_endpoint=f'ws://{node}.injective.network:26657/websocket'
             grpc_endpoint=f'{node}.injective.network:9900'
             grpc_exchange_endpoint=f'{node}.injective.network:9910'
 
         return cls(
             lcd_endpoint=lcd_endpoint,
+            tm_websocket_endpoint=tm_websocket_endpoint,
             grpc_endpoint=grpc_endpoint,
             grpc_exchange_endpoint=grpc_exchange_endpoint,
             chain_id='injective-1',
@@ -133,6 +139,7 @@ class Network:
     def local(cls):
         return cls(
             lcd_endpoint='http://localhost:10337',
+            tm_websocket_endpoint='ws://localost:26657/websocket',
             grpc_endpoint='localhost:9900',
             grpc_exchange_endpoint='localhost:9910',
             chain_id='injective-1',
@@ -140,5 +147,17 @@ class Network:
             env='local'
         )
 
+    @classmethod
+    def custom(cls, lcd_endpoint, tm_websocket_endpoint, grpc_endpoint, grpc_exchange_endpoint, chain_id, env):
+        return cls(
+            lcd_endpoint=lcd_endpoint,
+            tm_websocket_endpoint=tm_websocket_endpoint,
+            grpc_endpoint=grpc_endpoint,
+            grpc_exchange_endpoint=grpc_exchange_endpoint,
+            chain_id=chain_id,
+            fee_denom='inj',
+            env=env
+        )
+
     def string(self):
         return self.env
